#include <Wire.h>
#ifdef __AVR__
#include <avr/power.h>
#endif
#include "U8glib.h"         // Модуль экрана
#include <iarduino_DHT.h>   // подключаем библиотеку для работы с датчиком DHT
#include "RTClib.h"         // Модуль часов
#include <SoftwareSerial.h> // Библиотека витуального Serial
#include <avr/eeprom.h>


//Включение отладки
//#define _DEBUG

U8GLIB_SH1106_128X64 u8g(U8G_I2C_OPT_NONE);  // I2C / TWI

// Описание ног arduino
#include "define.h"            //Настройки
#include "my_mp3.h"
#include "dht11.h"

static unsigned char ico_t[] U8G_PROGMEM = { //Иконка температуры
  0xC0, 0x03, 0x60, 0xF6, 0x20, 0x04, 0x20, 0x04, 0x20, 0xF4, 0x20, 0x04,
  0x20, 0x04, 0x20, 0xF4, 0x20, 0x04, 0xA0, 0x05, 0xA0, 0xF5, 0xA0, 0x05,
  0xA0, 0x05, 0xA0, 0xF5, 0xA0, 0x05, 0xB0, 0x0D, 0x98, 0x19, 0xC8, 0x13,
  0xEC, 0x37, 0xE4, 0x27, 0xE4, 0x27, 0xEC, 0x37, 0xC8, 0x13, 0x18, 0x18,
  0x70, 0x0E, 0xC0, 0x03,
};

static unsigned char ico_h[] U8G_PROGMEM = { //Иконка влажности
  0x80, 0x01, 0x80, 0x01, 0xC0, 0x03, 0x40, 0x02, 0x60, 0x06, 0x20, 0x04,
  0x30, 0x0C, 0x10, 0x08, 0x18, 0x18, 0x08, 0x10, 0x0C, 0x30, 0x44, 0x24,
  0xA6, 0x64, 0xA2, 0x46, 0x43, 0xC2, 0x01, 0x83, 0x01, 0x81, 0x81, 0x81,
  0x81, 0x84, 0xC1, 0xCA, 0x43, 0x4A, 0x42, 0x44, 0x06, 0x60, 0x0C, 0x30,
  0x38, 0x1C, 0xE0, 0x07,
};


void draw(void)
{
  u8g.drawXBMP( 112, 8, 16, 26, ico_t);
  u8g.drawXBMP( 0, 8, 16, 26, ico_h);
  u8g.setFont(u8g_font_gdr17n);
  u8g.setPrintPos(18, 22);
  u8g.print(h);
  u8g.setPrintPos(88, 22);
  u8g.print(t);
  //Мелодия
  if (set_play_folder>0) {
    u8g.setFont(u8g_font_gdr9n);
    u8g.setPrintPos(65, 12);    
    u8g.print(play_folder);
    if (play_files_folder<10) u8g.setPrintPos(65, 24);
    else if (play_files_folder<100) u8g.setPrintPos(61, 24);
    else if (play_files_folder<1000) u8g.setPrintPos(57, 24);
    else u8g.setPrintPos(53, 24);
    u8g.print(play_files_folder);
  }
 
  u8g.setFont(u8g_font_osb29n);
  u8g.setPrintPos(15, 63);
  if (change_H < 10) {
    u8g.print(0);
  }
  u8g.print(change_H);
  u8g.setPrintPos(70, 64);
  if (change_M < 10) {
    u8g.print(0);
  }
  u8g.print(change_M);
  if ((now.second() & 1) == 0) {
    u8g.setPrintPos(60, 59);
    u8g.print(":");
  }
}


void setup(void) {
#ifdef _DEBUG
  Serial.begin(115200);
#endif
  pinMode(pin_Gerkon,INPUT_PULLUP);

  // mp3 player init
  mp3.begin(9600);
  delay(500); 
  command(0x09, 0, 2);  // Выбор TF
  delay(200); 
  command(0x06, 0, 30); // Громкость

  rtc.begin();
  now = rtc.now();
  change_H = now.hour();
  change_M = now.minute();

  Read_DHT11();

  delay(1500);
  if ( u8g.getMode() == U8G_MODE_R3G3B2 ) {
    u8g.setColorIndex(255);     // white
  }
  else if ( u8g.getMode() == U8G_MODE_GRAY2BIT ) {
    u8g.setColorIndex(3);         // max intensity
  }
  else if ( u8g.getMode() == U8G_MODE_BW ) {
    u8g.setColorIndex(1);         // pixel on
  }
  else if ( u8g.getMode() == U8G_MODE_HICOLOR ) {
    u8g.setHiColorByRGB(255, 255, 255);
  }

  // Реле
  pinMode(pin_rele, OUTPUT);
  digitalWrite(pin_rele, LOW);
  mp3_read_max_file();
  randomSeed(now.minute());
    #ifdef _DEBUG
      Serial.println("end setup");
    #endif
  ir_setup();
// Если первичный зпуск записываем первоначальные значения
  if (eeprom_read_byte(20)!=55)
   { 
    for (int i=0;i<8;i++) eeprom_write_byte(i,num_folder[i]);
    eeprom_write_byte(16,h_off);
    eeprom_write_byte(17,h_on);
    eeprom_write_byte(20,55);
    
   }
// Считывем начальные значений
  for (int i=0;i<8;i++)
    {
      num_folder[i]=eeprom_read_byte(i);
      if (num_folder[i]>max_mp3_forders) num_folder[i]=0;
    }
   h_off=eeprom_read_byte(16);
   h_on=eeprom_read_byte(17);
}

void loop(void) {
  Read_DHT11();
  Relal_bridht = map(analogRead(pin_bridge), 0, 1023, 0, 255); // снятие яркости с резистора
  ir_loop();
 
   if (millis()-timer_change>3000)
    {
      now = rtc.now();
      change_H = now.hour();
      change_M = now.minute();
      play_time_ADVERT(change_H,change_M);
     }

  // При движении в темноте включить подсветку
  // При включкеном свете при движении включить музыку, сказать время 
  // При высокой влажности включить свет и запустить музыку
  // При нормализации влажности, ждать окончания мелодии

  //Яркость подсветки
  way_led = 0;
  sr501 = analogRead(pin_sr501);
  if (sr501 > 500) {
    way_led = 1;
    if (Relal_bridht > 100) 
      {
        set_play_folder = num_folder[choice_bird_rain()];
        //if (mp3_play_time==0) mp3_play_time=1;
      }
     } else if ((Relal_bridht < 100) && (h < h_off)) set_play_folder = 0;// прекратить воспроизведение
   //Громкость звука 
   if (Playflag)
    { 
     way_voice=0; 
     if (h > h_off) way_voice=10;
     if (h > h_on) way_voice=20;
     if (Relal_bridht > 100) way_voice=30;
    } else
      {
        set_play_folder = num_folder[choice_bird_rain()];
        way_voice=30;
      }
     if (Relal_bridht > 100) {
        way_led = 255;
     }
// Раз в секунду меняем громкость и проверяем окончание мелодии
if (millis()-timer_pleer>1000) {
  if (real_voice < way_voice) {
    real_voice++;
    command(0x06, 0, real_voice); // Громкость
    delay(100);
   }
  if (real_voice > way_voice) {
    real_voice--;
    command(0x06, 0, real_voice); // Громкость
    delay(100);
   }
   if (set_play_folder>0) mp3_next(0); 
  timer_pleer=millis();
 } 
  
  if (real_led < way_led) real_led++;
  if (real_led > way_led) real_led--;
  analogWrite(pin_led, real_led);

  // picture loop
  if (millis() - timer_u8g >500 ) {
    u8g.firstPage();
    do {
      draw();
    } while ( u8g.nextPage() );
    timer_u8g=millis();
  }
  // Сказать скоько время
}
